#
# spec file for package kdoctools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang
%define lname   libKF5DocTools5
%define _tar_path 5.45
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %global _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           kdoctools
Version:        5.45.0
Release:        lp150.1.8
%define kf5_version %{version}
Summary:        Create documentation from DocBook
License:        LGPL-2.1-or-later AND MIT
Group:          System/GUI/KDE
Url:            http://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FEATURE-OPENSUSE
Patch1:         0001-Also-return-KDE4-docs-in-documentationDirs.patch
BuildRequires:  cmake >= 3.0
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  karchive-devel >= %{_kf5_bugfix_version}
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel >= %{_kf5_bugfix_version}
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  perl-URI
BuildRequires:  cmake(Qt5Core) >= 5.6.0
Recommends:     %{name}-lang
# The XSL templates reference files in here
Requires:       docbook-xsl-stylesheets
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Provides tools to generate documentation in various format from DocBook files.

%package -n %lname
Summary:        Create documentation from DocBook
Group:          System/Libraries
Recommends:     %{name} = %{version}
%requires_ge libQt5Core5

%description -n %lname
Provides tools to generate documentation in various format from DocBook files.

%package devel
Summary:        Create documentation from DocBook
Group:          Development/Libraries/KDE
Requires:       %lname = %{version}
Requires:       %{name} = %{version}
Requires:       docbook-xsl-stylesheets
Requires:       extra-cmake-modules >= 1.8.0
Requires:       libxslt-devel
Requires:       cmake(Qt5Core) >= 5.6.0
Provides:       %{name}-devel-static = %{version}

%description devel
Provides tools to generate documentation in various format from DocBook files.
Development files.

%prep
%setup -q
%patch1 -p1

%lang_package
%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang %{name} --with-man --all-name
%endif

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%if %{with lang}
%files lang -f %{name}.lang
%endif

%files
%defattr(-,root,root)
%doc COPYING* README* LICENSE
%{_kf5_htmldir}/*/
%{_kf5_datadir}/kdoctools/
%{_kf5_bindir}/meinproc5
%{_kf5_bindir}/checkXML5
%doc %lang(en) %{_kf5_mandir}/*/meinproc5.*
%doc %lang(en) %{_kf5_mandir}/*/checkXML5.*
%doc %lang(en) %{_kf5_mandir}/*/kf5options.*
%doc %lang(en) %{_kf5_mandir}/*/qt5options.*

%files -n %lname
%defattr(-,root,root)
%doc COPYING* README*
%{_kf5_libdir}/libKF5DocTools.so.*

%files devel
%defattr(-,root,root)
%{_kf5_libdir}/cmake/KF5DocTools/
%dir %{_kf5_includedir}/*/
%{_kf5_includedir}/*/
%{_libdir}/libKF5DocTools.so

%changelog
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add entities for Elisa, Markdown, KParts, DOT, SVG to general.entities
  * customization/ru: Fix translation of underCCBYSA4.docbook and underFDL.docbook
  * Fix duplicate lgpl-notice/gpl-notice/fdl-notice
  * customization/ru: Translate fdl-notice.docbook
  * change spelling of kwave requested by the maintainer
  * Remove not necessary QtCore and co
- Don't mark /usr/share/doc/HTML*/kdoctools5-common as %%doc,
  they're files needed to display help properly (boo#1088562)
* Tue Mar 13 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Tue Feb 13 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * customization/entities/contributor.entities - fix typo . missing '>'
  * rename KDE-Partitionsmanager to Partitionsverwaltung, KDE does not make any sense here
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * add entity for Michael Pyne
  * Remove obsolete reviewboardrc file
  * add entities for Martin Koller to contributor.entities
  * fix debian entry
  * add entity Debian to general.entities
  * add entity kbackup, it was imported
  * add entity latex, we have already 7 entities in different index.docbooks in kf5
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Update Brasilian Portuguese translation
  * Update Russian translation
  * Update Russian translation
  * Update customization/xsl/ru.xml (nav-home was missing)
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * Update Catalan translation
  * Update Ukrainian translation
  * Add .arcconfig
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * None
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * CMake: Fix target name shortening when build dir has special characters (kde#377573)
  * Add CC BY-SA 4.0 International and set it as default
* Sun Aug 20 2017 fabian@ritter-vogt.de
- Require docbook-xsl-stylesheets, the included XSL files reference
  docbook XSL files
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Move meinproc5's man page from section 8 to section 1
* Tue Jul 25 2017 fabian@ritter-vogt.de
- Add patch to also return the KDE4 documentation directories:
  * 0001-Also-return-KDE4-docs-in-documentationDirs.patch
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * New function to retrieve the documentation directories
  * Fix a few MSVC warnings
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * add entity kmplayer
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Workaround for MSVC and catalog loading
  * Solve a visibility conflict for meinproc5 (kde#379142)
  * Quote few other variables with path (avoid issues with spaces)
  * Quote few variables with path (avoid issues with spaces)
  * Temporarily disable the local doc on Windows
  * FindDocBookXML4.cmake, FindDocBookXSL.cmake - search in homebrew installations
- Use %%find_lang --all-name --with-man for .lang filelist
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
  * meinproc5: link to the files, not to the library
* Mon Mar 20 2017 lbeltrame@kde.org
- Add a new subpackage to track the new shared library provided
  by doctools
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * meinproc5: link to the files, not to the library
  * Commit translations from l10n-kf5
  * Remove the KF5::XsltKde static library
  * Port to categorized logging and clean includes
  * Export a proper shared library for KDocTools
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Add function to extract a single file
  * Revert "Port to categorized logging and clean includes"
  * Port to categorized logging and clean includes
  * Fail the build early if xmllint is not available
  * Upgrade KF5 version to 5.32.0.
  * add entity for application Kst
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sun Nov  6 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Fix 'checkXML5 generates html files in workdir for
    valid docbooks' (kde#371987)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * Fix 'checkXML5 prints generated html to stdout for valid docbooks'
    (kde#369415)
  * Fix bug not been able to run native tools in package using cross
    compiled kdoctools
  * Setup targets for cross compiling running kdoctools from
    other packages
  * Add cross compiling support for docbookl10nhelper
  * Add cross compile support for meinproc5
  * Convert checkxml5 into a qt executable for cross platform support
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Add paths for config, cache + data to general.entities
  * Made up-to-date with the English version
  * Add Space and Meta key entities to
    src/customization/en/user.entities
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Allow KDocTools to always locate at least its own installed stuff
  * Use CMAKE_INSTALL_DATAROOTDIR to look for docbook instead of share
  * Update qt5options manpage docbook to qt 5.4
  * Update kf5options manpage docbook
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Add commonly used entities for keys to en/user.entities
  * Update man-docbook template
  * Update book template + man template + add arcticle template
  * Call kdoctools_create_handbook only for index.docbook
    (kde#357428)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Added entity applications
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Use unicode characters for callouts
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Fri Dec 11 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Update pt_BR entities
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * Sync Catalan user.entities with English (en) version.
  * Add entities for sebas and plasma-pa
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Change sentence about reporting bugs, ack'ed by dfaure
  * Adapt german user.entities to en/user.entities
  * Update general.entities: change markup for frameworks + plasma
    from application to productname
  * Update en/user.entities
  * Update book and man page templates
  * Use CMAKE_MODULE_PATH in cmake_install.cmake
  * Update general.entities
  * Search for required perl modules.
  * Namespace a helper macro in the installed macros file.
  * Adapted key name tranlations to standard tranlations provided
    by Termcat
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * Update K5 docbook templates
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * Update translations
  * Update customization/ru
  * Fix entities with wrong links
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Fix the build on MacOSX when using Homebrew
  * Better styling of media objects (images, ...) in documentation
  * Encode invalid chars in paths used in XML DTDs, avoiding errors
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
- Drop karchive-devel from devel package requires
- Added perl-URI buildrequires
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Thu Oct 16 2014 vpelcak@suse.com
- moving meinproc and checkXML5 and manpages to main package.
  Reason is to make these tools available to translators, who use
  automated tools for translation handling (pology) without need
  to install devel package which brings many otherwise unnecessary
  dependencies
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Added ki18n-devel for new lang subpackage
- Let main package Recommend lang package
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Define kf5_version within package
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Fri Feb 21 2014 hrvoje.senjan@gmail.com
- Mark license as LGPL-2.1+ and MIT
- Include license as %%doc
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kdoctools package
